pub struct Ref<'a, T> { /* private fields */ }Expand description
Returns a reference to the inner value.
Outstanding borrows hold a read lock on the inner value. This means that long lived borrows could cause the produce half to block. It is recommended to keep the borrow as short lived as possible.